summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.hgignore2
-rw-r--r--docs/conf.py75
2 files changed, 47 insertions, 30 deletions
diff --git a/.hgignore b/.hgignore
index d9365fb..5acfdea 100644
--- a/.hgignore
+++ b/.hgignore
@@ -3,3 +3,5 @@ glob:*.pyc
glob:*.egg-info
glob:.coverage
glob:cover
+glob:build
+glob:dist
diff --git a/docs/conf.py b/docs/conf.py
index eea6772..adfa516 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -5,16 +5,13 @@
#
# This file is execfile()d with the current directory set to its containing dir.
#
-# The contents of this file are pickled, so don't put values in the namespace
-# that aren't pickleable (module imports are okay, they're removed automatically).
-#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.
-import os, sys
+import sys, os
options = os.environ.get("PASSLIB_DOCS", "")
@@ -23,27 +20,31 @@ doc_root = os.path.abspath(os.path.join(__file__,os.path.pardir))
source_root = os.path.abspath(os.path.join(doc_root,os.path.pardir))
sys.path.insert(0, source_root)
-#building docs requires Assurance Technologies' AstDoc library
-# http://www.assurancetechnologies.com/software/astdoc
-#which contains some sphinx extensions used by passlib
-import astdoc
-
# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
-##sys.path.append(os.path.abspath(os.path.join(__file__,"..","_exts")))
+#sys.path.insert(0, os.path.abspath('.'))
+
+#building the docs requires Assurance Technologies' AstDoc library
+# https://bitbucket.org/ecollins/astdoc
+#which contains some sphinx extensions used by passlib
+import astdoc
+
# -- General configuration -----------------------------------------------------
+# If your documentation needs a minimal Sphinx version, state it here.
+needs_sphinx = '1.0'
+
# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
'sphinx.ext.autodoc',
'sphinx.ext.todo',
- 'astdoc.ext.index_styles', #adds extra ids & classes to index html, for additional styling
+ 'astdoc.ext.autodoc_sections', #add autdoc support for ReST sections in class/function docstrings
+ 'astdoc.ext.index_styling', #adds extra ids & classes to genindex html, for additional styling
'astdoc.ext.relbar_toc', #inserts toc into right hand nav bar (ala old style python docs)
- 'astdoc.ext.nested_sections', #handles ReST markup within function/class docstrings
]
# Add any paths that contain templates here, relative to this directory.
@@ -83,15 +84,12 @@ version = astdoc.get_version(release)
# Else, today_fmt is used as the format for a strftime call.
#today_fmt = '%B %d, %Y'
-# List of documents that shouldn't be included in the build.
-unused_docs = [ ]
-
-# List of directories, relative to source directory, that shouldn't be searched
-# for source files.
-exclude_trees = ['_build']
+# List of patterns, relative to source directory, that match files and
+# directories to ignore when looking for source files.
+exclude_patterns = []
# The reST default role (used for this markup: `text`) to use for all documents.
-##default_role = 'obj'
+#default_role = None
# If true, '()' will be appended to :func: etc. cross-reference text.
add_function_parentheses = True
@@ -116,13 +114,8 @@ keep_warnings = "hide-warnings" not in options
# -- Options for HTML output ---------------------------------------------------
-# The style sheet to use for HTML and HTML Help pages. A file of that name
-# must exist either in Sphinx' static/ path, or in one of the custom paths
-# given in html_static_path.
-##html_style = 'xxx.css'
-
-# The theme to use for HTML and HTML Help pages. Major themes that come with
-# Sphinx are currently 'default' and 'sphinxdoc'.
+# The theme to use for HTML and HTML Help pages. See the documentation for
+# a list of builtin themes.
html_theme = 'cloud'
# Theme options are theme-specific and customize the look and feel of a theme
@@ -173,7 +166,7 @@ html_use_smartypants = True
#html_additional_pages = {}
# If false, no module index is generated.
-#html_use_modindex = True
+#html_domain_indices = True
# If false, no index is generated.
#html_use_index = True
@@ -184,13 +177,19 @@ html_use_smartypants = True
# If true, links to the reST sources are added to the pages.
#html_show_sourcelink = True
+# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
+#html_show_sphinx = True
+
+# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
+#html_show_copyright = True
+
# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it. The value of this option must be the
# base URL from which the finished HTML is served.
#html_use_opensearch = ''
-# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
-#html_file_suffix = ''
+# This is the file name suffix for HTML files (e.g. ".xhtml").
+#html_file_suffix = None
# Output file base name for HTML help builder.
htmlhelp_basename = project + 'Doc'
@@ -219,6 +218,12 @@ latex_documents = [
# not chapters.
#latex_use_parts = False
+# If true, show page references after internal links.
+#latex_show_pagerefs = False
+
+# If true, show URL addresses after external links.
+#latex_show_urls = False
+
# Additional stuff for the LaTeX preamble.
#latex_preamble = ''
@@ -226,4 +231,14 @@ latex_documents = [
#latex_appendices = []
# If false, no module index is generated.
-#latex_use_modindex = True
+#latex_domain_indices = True
+
+
+# -- Options for manual page output --------------------------------------------
+
+# One entry per manual page. List of tuples
+# (source start file, name, description, authors, manual section).
+man_pages = [
+ (index_doc, project, project + u' Documentation',
+ [u'Assurance Technologies, LLC'], 1)
+]